# Motivation, your way - Experiment analysis to compare effects of tailored messages vs generic messages

This repository contains the data and the code related to the experiment conducted to test the effect of tailored and generic messages on motivation. It only reports the results obtained from the experimental data. For a comprehensive discussion about the results, please refer to the thesis uploaded at <LINK_TO_THESIS>.

## Contents of the repository
```
experiment
│   Dockerfile
│   README.md
│   Statistical Analysis.Rmd 
│   Demographic Analysis.Rmd
│   Prior Sensitivity Analysis.Rmd
|   Motivating factors.png
|   Demotivating factors.png
│
└───data
│   │   experiment_data.csv
│   │   Columns explanation.xlsx
│
└───scripts
│   │   preprocessing.r
│
└───results
│   │   Statistical Analysis.pdf
│   │   Demographic Analysis.pdf
│   │   Prior Sensitivity Analysis.pdf
```

| File/Folder name                 | Content                                                                                   |
| -------------------------------- | ----------------------------------------------------------------------------------------- |
| Dockerfile                       | File containing instructions to build Docker image                                        |
| README.md                        | The file you are currently reading - Contains project information                         |
| Statistical Analysis.Rmd         | R Markdown file containing statistical models for analysis                                |
| Demographic Analysis.Rmd         | R Markdown file containing analysis of participants' characteristics and demographic data |
| Prior Sensitivity Analysis.Rmd   | R Markdown file containing prior sensitivity analysis                                     |
| Motivating factors.png           | Thematic analysis of motivating factors                                                   |
| Demotivating factors.png         | Thematic analysis of demotivating factors                                                 |
| data/                            | Folder containing csv files - data from the experiments                                   |
| - experiment_data.csv            | Approved participants' data and their responses                                           |
| - Columns explanation.xlsx       | Explanation of the columns present in experiment_data.csv                                 |
| scripts/                         | Folder containing utility R scripts to help with analysis                                 |
| - preprocessing.r                | Preprocessing script to clean up and organize data                                        |
| results/                         | Folder containing utility R scripts to help with analysis                                 |
| - Statistical-Analysis.pdf       | Pdf file knit from `Statistical Analysis.Rmd`                                             |
| - Demographic-Analysis.pdf       | Pdf file knit from `Demographic Analysis.Rmd`                                             |
| - Prior-Sensitivity-Analysis.pdf | Pdf file knit from `Prior Sensitivity Analysis.Rmd`                                       |

## Initial Setup
Pre-requisites:
- Docker (You can follow the instructions [here](https://docs.docker.com/get-docker/))

## Obtaining the Docker image

You can build the Docker image in one of two ways:
- Pull the Docker image from Docker Hub using the following command:
```
docker pull rghantasala/statistical-analysis-with-r
```
OR
- Build the image from the given Dockerfile
- - Ensure Docker daemon is running
- - Open Terminal or Command Prompt
- - Run the following command:
```
docker build -f /path/to/a/Dockerfile -t <DOCKER_IMAGE_NAME> .
```
More information regarding `Dockerfile` and how to build images can be found [here](https://docs.docker.com/engine/reference/builder/)

## Running the Docker container

Use the following command to run a Docker container from the Docker image you have built from the previous step. 
```
docker run -d -p 8787:8787 -v <PATH_TO_CURRENT_FOLDER>:/home/rstudio/analysis -e PASSWORD=<PASSWORD> <DOCKER_IMAGE_NAME>
```

If you are running a container from the image pulled from Docker Hub, the command should look something like this:
```
docker run -d -p 8787:8787 -v <PATH_TO_CURRENT_FOLDER>:/home/rstudio/analysis -e PASSWORD=<PASSWORD> rghantasala/statistical-analysis-with-r
```

- If the container has started successfully, you should see a new container in Docker Desktop under `Containers/Apps`.
- Navigate to `https://localhost:8787`, and you should see a login page for RStudio. Enter `rstudio` as the username, and the password you specified when you ran the container to login.
- Voila! You have RStudio running in your browser.


## Knitting from the command line

To knit the `.RmD` files from the command line of the docker containers, run the following commands:

- `docker ps # Find the `CONTAINER ID` of the container running RStudio. If you already have the container id, skip to the next step.`
- `docker exec -it -w /home/rstudio/analysis <CONTAINER_ID> /bin/bash # This will open a bash shell at /home/rstudio/analysis in the container`
- `R -e "rmarkdown::render('<NAME_OF_RMD_FILE>', 'pdf_document')" #Knit the required RmD file`

## Knitting from RStudio

To knit the `.RmD` files from RStudio:

- Navigate to `http://localhost:8787/` after starting the Docker container.
- Open one of the `.RmD` files, and select "Knit to PDF" from the toolbar.

## Results
- The `results/` folder contains the pdfs knit from the Rmd files present in the root folder. To reproduce the results, run the corresponding R Markdown files to inspect the output, or knit to pdf to get the results neatly printed in a pdf format. The knit files will be generated in the `analysis/` folder.

## Tables/figures and corresponding files

| File Name                | Corresponding figure/table in the report                                                 |
|--------------------------|------------------------------------------------------------------------------------------|
| Demographic Analysis.RmD | Table 4.2: Participant Characteristics                                                   |
| Statistical Analysis.RmD | Figure 4.4: Comparison of the motivation of the two message types.                       |
| Statistical Analysis.RmD | Table 4.3: Summary of model 2                                                            |
| Statistical Analysis.RmD | Figure 4.5: Comparison of the two models fitted on motivation.                           |
| Motivating factors.png   | Figure 4.6: Thematic analysis of factors participating found  motivating in a message.   |
| Demotivating factors.png | Figure 4.7: Thematic analysis of factors participating found  demotivating in a message. |